==> jc-1.4.0.tar.gz: soot/shimple/AbstractShimpleValueSwitch.h <==
// public abstract class soot.shimple.AbstractShimpleValueSwitch

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 284aff14bea3930f soot_jimple_AbstractJimpleValueSwitch
// @dep_class a4b52938ac02d1b0 soot_shimple_AbstractShimpleValueSwitch

// header file dependencies
// @dep_header soot_jimple_AbstractJimpleValueSwitch

#include "soot/jimple/AbstractJimpleValueSwitch.h"

#ifndef _JC_soot_shimple_AbstractShimpleValueSwitch_H_
#define _JC_soot_shimple_AbstractShimpleValueSwitch_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_shimple_PhiExpr$object;

// Typedefs
typedef struct _jc_soot_shimple_AbstractShimpleValueSwitch$sub_refs	_jc_soot_shimple_AbstractShimpleValueSwitch$sub_refs;
typedef struct _jc_soot_shimple_AbstractShimpleValueSwitch$sub_nonrefs	_jc_soot_shimple_AbstractShimpleValueSwitch$sub_nonrefs;
typedef struct _jc_soot_shimple_AbstractShimpleValueSwitch$refs	_jc_soot_shimple_AbstractShimpleValueSwitch$refs;
typedef struct _jc_soot_shimple_AbstractShimpleValueSwitch$nonrefs	_jc_soot_shimple_AbstractShimpleValueSwitch$nonrefs;
typedef struct _jc_soot_shimple_AbstractShimpleValueSwitch$object	_jc_soot_shimple_AbstractShimpleValueSwitch$object;

typedef const struct _jc_soot_shimple_AbstractShimpleValueSwitch$vmethods	_jc_soot_shimple_AbstractShimpleValueSwitch$vmethods;
typedef const struct _jc_soot_shimple_AbstractShimpleValueSwitch$vtable	_jc_soot_shimple_AbstractShimpleValueSwitch$vtable;
typedef const struct _jc_soot_shimple_AbstractShimpleValueSwitch$vtype	_jc_soot_shimple_AbstractShimpleValueSwitch$vtype;

// Constructors
extern void _jc_soot_shimple_AbstractShimpleValueSwitch$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_shimple_AbstractShimpleValueSwitch$object *);

// Virtual methods
extern void _jc_soot_shimple_AbstractShimpleValueSwitch$method$casePhiExpr$c285db4a50a108e9(_jc_env *, struct _jc_soot_shimple_AbstractShimpleValueSwitch$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_shimple_AbstractShimpleValueSwitch$method_info$casePhiExpr$c285db4a50a108e9;

// Virtual methods structure
struct _jc_soot_shimple_AbstractShimpleValueSwitch$vmethods {
	void	(*casePhiExpr$c285db4a50a108e9)(_jc_env *, struct _jc_soot_shimple_AbstractShimpleValueSwitch$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_shimple_AbstractShimpleValueSwitch$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_AbstractJimpleValueSwitch$vmethods	soot_jimple_AbstractJimpleValueSwitch;
	_jc_soot_shimple_AbstractShimpleValueSwitch$vmethods	soot_shimple_AbstractShimpleValueSwitch;
};

// Vtype
struct _jc_soot_shimple_AbstractShimpleValueSwitch$vtype {
	_jc_type			type;
	_jc_soot_shimple_AbstractShimpleValueSwitch$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_shimple_AbstractShimpleValueSwitch$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_shimple_AbstractShimpleValueSwitch$refs {
    _jc_soot_shimple_AbstractShimpleValueSwitch$sub_refs	soot_shimple_AbstractShimpleValueSwitch;
    _jc_soot_jimple_AbstractJimpleValueSwitch$sub_refs	soot_jimple_AbstractJimpleValueSwitch;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_shimple_AbstractShimpleValueSwitch$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_shimple_AbstractShimpleValueSwitch$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_AbstractJimpleValueSwitch$sub_nonrefs	soot_jimple_AbstractJimpleValueSwitch;
    _jc_soot_shimple_AbstractShimpleValueSwitch$sub_nonrefs	soot_shimple_AbstractShimpleValueSwitch;
};

// Object instance structure
struct _jc_soot_shimple_AbstractShimpleValueSwitch$object {
	_jc_soot_shimple_AbstractShimpleValueSwitch$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_shimple_AbstractShimpleValueSwitch$vtype	*vtype;
	_jc_soot_shimple_AbstractShimpleValueSwitch$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_shimple_AbstractShimpleValueSwitch$vtype _jc_soot_shimple_AbstractShimpleValueSwitch$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_shimple_AbstractShimpleValueSwitch, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_shimple_AbstractShimpleValueSwitch$class_object;

#endif	/* _JC_soot_shimple_AbstractShimpleValueSwitch_H_ */

==> jc-1.4.6.tar.gz: soot/shimple/AbstractShimpleValueSwitch.h <==
// public abstract class soot.shimple.AbstractShimpleValueSwitch

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 284aff14bea3930f soot_jimple_AbstractJimpleValueSwitch
// @dep_class a4b52938ac02d1b0 soot_shimple_AbstractShimpleValueSwitch

// header file dependencies
// @dep_header soot_jimple_AbstractJimpleValueSwitch

#include "soot/jimple/AbstractJimpleValueSwitch.h"

#ifndef _JC_soot_shimple_AbstractShimpleValueSwitch_H_
#define _JC_soot_shimple_AbstractShimpleValueSwitch_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_shimple_PhiExpr$object;

// Typedefs
typedef struct _jc_soot_shimple_AbstractShimpleValueSwitch$sub_refs	_jc_soot_shimple_AbstractShimpleValueSwitch$sub_refs;
typedef struct _jc_soot_shimple_AbstractShimpleValueSwitch$sub_nonrefs	_jc_soot_shimple_AbstractShimpleValueSwitch$sub_nonrefs;
typedef struct _jc_soot_shimple_AbstractShimpleValueSwitch$refs	_jc_soot_shimple_AbstractShimpleValueSwitch$refs;
typedef struct _jc_soot_shimple_AbstractShimpleValueSwitch$nonrefs	_jc_soot_shimple_AbstractShimpleValueSwitch$nonrefs;
typedef struct _jc_soot_shimple_AbstractShimpleValueSwitch$object	_jc_soot_shimple_AbstractShimpleValueSwitch$object;

typedef const struct _jc_soot_shimple_AbstractShimpleValueSwitch$vmethods	_jc_soot_shimple_AbstractShimpleValueSwitch$vmethods;
typedef const struct _jc_soot_shimple_AbstractShimpleValueSwitch$vtable	_jc_soot_shimple_AbstractShimpleValueSwitch$vtable;
typedef const struct _jc_soot_shimple_AbstractShimpleValueSwitch$vtype	_jc_soot_shimple_AbstractShimpleValueSwitch$vtype;

// Constructors
extern void _jc_soot_shimple_AbstractShimpleValueSwitch$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_shimple_AbstractShimpleValueSwitch$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_shimple_AbstractShimpleValueSwitch$method$casePhiExpr$c285db4a50a108e9(_jc_env *, struct _jc_soot_shimple_AbstractShimpleValueSwitch$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_shimple_AbstractShimpleValueSwitch$method_info$casePhiExpr$c285db4a50a108e9;

// Virtual methods structure
struct _jc_soot_shimple_AbstractShimpleValueSwitch$vmethods {
	void	(*casePhiExpr$c285db4a50a108e9)(_jc_env *, struct _jc_soot_shimple_AbstractShimpleValueSwitch$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_shimple_AbstractShimpleValueSwitch$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_AbstractJimpleValueSwitch$vmethods	soot_jimple_AbstractJimpleValueSwitch;
	_jc_soot_shimple_AbstractShimpleValueSwitch$vmethods	soot_shimple_AbstractShimpleValueSwitch;
};

// Vtype
struct _jc_soot_shimple_AbstractShimpleValueSwitch$vtype {
	_jc_type			type;
	_jc_soot_shimple_AbstractShimpleValueSwitch$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_shimple_AbstractShimpleValueSwitch$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_shimple_AbstractShimpleValueSwitch$refs {
    _jc_soot_shimple_AbstractShimpleValueSwitch$sub_refs	soot_shimple_AbstractShimpleValueSwitch;
    _jc_soot_jimple_AbstractJimpleValueSwitch$sub_refs	soot_jimple_AbstractJimpleValueSwitch;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_shimple_AbstractShimpleValueSwitch$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_shimple_AbstractShimpleValueSwitch$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_AbstractJimpleValueSwitch$sub_nonrefs	soot_jimple_AbstractJimpleValueSwitch;
    _jc_soot_shimple_AbstractShimpleValueSwitch$sub_nonrefs	soot_shimple_AbstractShimpleValueSwitch;
};

// Object instance structure
struct _jc_soot_shimple_AbstractShimpleValueSwitch$object {
	_jc_soot_shimple_AbstractShimpleValueSwitch$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_shimple_AbstractShimpleValueSwitch$vtype	*vtype;
	_jc_soot_shimple_AbstractShimpleValueSwitch$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_shimple_AbstractShimpleValueSwitch$vtype _jc_soot_shimple_AbstractShimpleValueSwitch$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_shimple_AbstractShimpleValueSwitch, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_shimple_AbstractShimpleValueSwitch$class_object;

#endif	/* _JC_soot_shimple_AbstractShimpleValueSwitch_H_ */
